class ErrorCode(object):
    NO_AVAILABLE_INITIAL_STATE = 1
    NO_AVAILABLE_FINAL_STATE = 2
    MULTIPLE_INITIAL_STATE = 3
    NO_AVAILABLE_NEXT_STATE_FOR_USER = 4
    INVALID_NEXT_STATE_FOR_USER = 5
    NEXT_STATE_IS_REQUIRED = 6

    MULTIPLE_STATE_FIELDS = 7
    NO_STATE_FIELD = 8
    ALREADY_SKIPPED = 9
    STATE_IS_NOT_AVAILABLE_TO_BE_JUMPED = 10
